@@ -155,7 +155,7 @@ specify '--server <servername>' as an argument. Boolean settings translate into
 '--setting' and '--no-setting' pairs.
 
 See the configuration file documentation at
-https://docs.puppetlabs.com/references/stable/configuration.html for the
+https://docs.puppetlabs.com/puppet/latest/reference/configuration.html for the
 full list of acceptable settings. A commented list of all settings can also be
 generated by running puppet agent with '--genconfig'.
 
