@@ -19,20 +19,32 @@ module Puppet::DataProviders::HieraInterpolate
 
   private
 
+  EMPTY_INTERPOLATIONS = {
+    '' => true,
+    '::' => true,
+    '""' => true,
+    "''" => true,
+    '"::"' => true,
+    "'::'" => true
+  }.freeze
+
+  # Matches a key that is quoted using a matching pair of either single or double quotes.
+  QUOTED_KEY = /^(?:"([^"]+)"|'([^']+)')$/
+
   def interpolate_string(subject, lookup_invocation, allow_methods)
     lookup_invocation.with(:interpolate, subject) do
       subject.gsub(/%\{([^\}]*)\}/) do |match|
         expr = $1
         # Leading and trailing spaces inside an interpolation expression are insignificant
         expr.strip!
-        unless expr.empty? || expr == '::'
+        unless EMPTY_INTERPOLATIONS[expr]
           method_key, key = get_method_and_data(expr, allow_methods)
           is_alias = method_key == 'alias'
 
           # Alias is only permitted if the entire string is equal to the interpolate expression
           raise Puppet::DataBinding::LookupError, "'alias' interpolation is only permitted if the expression is equal to the entire string" if is_alias && subject != match
 
-          segments = key.split('.')
+          segments = split_key(key) { |problem| Puppet::DataBinding::LookupError.new("#{problem} in string: #{subject}") }
           value = interpolate_method(method_key).call(segments[0], lookup_invocation)
           value = qualified_lookup(segments.drop(1), value) if segments.size > 1
           value = lookup_invocation.check(key) { interpolate(value, lookup_invocation, allow_methods) }
@@ -76,7 +88,7 @@ module Puppet::DataProviders::HieraInterpolate
         'alias' => global_lookup, # same as 'lookup' but expression must be entire string. The result that is not subject to string substitution
         'scope' => scope_lookup,
         'literal' => lambda { |key, _| key }
-      }
+      }.freeze
     end
     interpolate_method = @@interpolate_methods[method_key]
     raise Puppet::DataBinding::LookupError, "Unknown interpolation method '#{method_key}'" unless interpolate_method
@@ -109,4 +121,35 @@ module Puppet::DataProviders::HieraInterpolate
     end
     [key, data]
   end
+
+  # Split key into segments. A segment may be a quoted string (both single and double quotes can
+  # be used) and the segment separator is the '.' character. Whitespace will be trimmed off on
+  # both sides of each segment. Whitespace within quotes are not trimmed.
+  #
+  # If the key cannot be parsed, this method will yield a string describing the problem to a one
+  # parameter block. The block must return an exception instance.
+  #
+  # @param key [String] the string to split
+  # @return Array<String> the array of segments
+  # @yieldparam problem [String] the problem, i.e. 'Syntax error'
+  # @yieldreturn [Exception] the exception to raise
+  def split_key(key)
+    segments = key.split(/(\s*"[^"]+"\s*|\s*'[^']+'\s*|[^'".]+)/)
+    if segments.empty?
+      # Only happens if the original key was an empty string
+      ''
+    elsif segments.shift == ''
+      count = segments.size
+      raise yield('Syntax error') unless count > 0
+
+      segments.keep_if { |seg| seg != '.' }
+      raise yield('Syntax error') unless segments.size * 2 == count + 1
+      segments.map! do |segment|
+        segment.strip!
+        segment.start_with?('"') || segment.start_with?("'") ? segment[1..-2] : segment
+      end
+    else
+      raise yield('Syntax error')
+    end
+  end
 end
